<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

namespace format_iena\output;

use core_courseformat\output\section_renderer;


class renderer extends section_renderer {

    /**
     * Displays the activities list in cases when course view page is not
     * redirected to the activity page.
     *
     * @param stdClass $course record from table course
     * @param bool $orphaned if false displays the main activity (if present)
     *     if true displays all other activities
     */
   /**
     * Renders the provided widget and returns the HTML to display it.
     *
     * Course format templates uses a similar subfolder structure to the renderable classes.
     * This method find out the specific template for a course widget. That's the reason why
     * this render method is different from the normal plugin renderer one.
     *
     * course format templatables can be rendered using the core_course/local/* templates.
     * Format plugins are free to override the default template location using render_xxx methods as usual.
     *
     * @param \renderable $widget instance with renderable interface
     * @return string the widget HTML
     */
    public function render(\renderable $widget) {
        global $CFG;
        $fullpath = str_replace('\\', '/', get_class($widget));
        $classparts = explode('/', $fullpath);
        // Strip namespaces.
        $classname = array_pop($classparts);
        // Remove _renderable suffixes.
        $classname = preg_replace('/_renderable$/', '', $classname);

        $rendermethod = 'render_' . $classname;
        if (method_exists($this, $rendermethod)) {
            return $this->$rendermethod($widget);
        }
        // Check for special course format templatables.
        if ($widget instanceof \templatable) {
            // Templatables from both core_courseformat\output\xxx_format\* and format_xxx\output\xxx_format\*
            // use core_crouseformat/local/xxx_format templates by default.
            $corepath = 'core_courseformat\/output\/local';
            $pluginpath = 'format_.+\/output\/courseformat';
            $specialrenderers = '/^(?<componentpath>' /*. $corepath . '|'*/ . $pluginpath . ')\/(?<template>.+)$/'; // CHANGED.
            $matches = null;
            if (preg_match($specialrenderers, $fullpath, $matches)) {
                $data = $widget->export_for_template($this);
                return $this->render_from_template('format_iena/courseformat/' . $matches['template'], $data);    // CHANGED.
            }
        }
        // If nothing works, let the parent class decide.
        return parent::render($widget);
    }

    //Permet d'ajouter l'édition rapide sur les sections
    /**
     * Generate the section title, wraps it in a link to the section page if page is to be displayed on a separate page
     *
     * @param stdClass $section The course_section entry from DB
     * @param stdClass $course The course entry from DB
     * @return string HTML to output.
     */
    public function section_title($section, $course) {
        return $this->render(course_get_format($course)->inplace_editable_render_section_name($section));
    }

    /**
     * Generate the section title to be displayed on the section page, without a link
     *
     * @param stdClass $section The course_section entry from DB
     * @param stdClass $course The course entry from DB
     * @return string HTML to output.
     */
    public function section_title_without_link($section, $course) {
        return $this->render(course_get_format($course)->inplace_editable_render_section_name($section, false));
    }

     public function display_completion($data){
        echo $this->render_from_template('format_iena/suivi', $data);
    }

    public function display_table_completion($data){
        echo $this->render_from_template('format_iena/suivi-table', $data);
    }

    public function display_message($data){
        echo $this->render_from_template('format_iena/send-message', $data);
    }

    public function display_edit_page($data){
        echo $this->render_from_template('format_iena/suivi-edit', $data);
    }


}
