<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
/**
 *
 * course_format_iena_sections
 *
 * @package    format_iena
 * @copyright  2018 Softia/Université lorraine
 * @author     vrignaud camille / Michaël Lebeau
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

class course_format_iena_sections {
    /** @var int id of section */
    public $id;
    /** @var string name of section */
    public $name;
    /** @var int id of course */
    public $idcourse;
    /** @var block_career_resources array<Ressource> resources */
    public $resources;
    /** @var date */
    public $date;
    /** @var string availability */
    public $availability;
    public $visibility;

    /**
     * @param $idcourse
     * @return array
     * @throws dml_exception
     */
    public function get_sections_by_id_course($idcourse) {
        global $DB;
        $requete = $DB->get_records_sql('SELECT *
            FROM {course_sections}
            WHERE course = ?
            ORDER BY section',
            array($idcourse));

        return $requete;
        $sections = array();
        $i = 0;
        foreach ($requete as $value) {
            $section = new course_format_iena_sections();
            $section->get_section_by_id_section($value->id);
            $sections[$i] = $section;
            $i++;
        }
        return $sections;
    }

    /**
     * @param $idsection
     * @throws dml_exception
     */
    public function get_section_by_id_section($idsection) {
        global $DB;
        $requete = $DB->get_record_sql('SELECT *
            FROM {course_sections}
            WHERE id = ?',
            array($idsection));
        $this->id = $requete->id;
        $this->name = $requete->name;
        $this->id_course = $requete->course;

        if (!$this->name) {
            $this->name = get_string('section', 'format_iena') . " " . $requete->section;
        }
    }

    /**
     * @param $idsection
     * @return mixed
     * @throws dml_exception
     */
    public function get_section_settings_by_id_section($idsection) {
        global $DB;
        $requete = $DB->get_record_sql('SELECT *
            FROM {format_iena}
            WHERE id_section = ?',
            array($idsection));
        return $requete;
    }

    /**
     * @param $idsection
     * @param $iduser
     * @return array
     * @throws dml_exception
     */
    public function get_completion_by_sectionID_userID($idsection, $iduser) {
        global $DB;
        $requete = $DB->get_records_sql('SELECT cmc.id as moduleid, cm.course, cm.section, cmc.userid, cmc.completionstate
            FROM {course_modules} cm
            INNER JOIN  {course_modules_completion} cmc ON cmc.coursemoduleid = cm.id
            WHERE cm.section= ?
            AND cmc.userid= ?
            ORDER BY cm.section, cmc.userid',
            array($idsection, $iduser));
        return $requete;
    }

    /**
     * @param $idsection
     * @return array
     * @throws dml_exception
     */
    public function get_hidden_modules_by_section($idsection) {
        global $DB;
        $requete = $DB->get_records_sql('SELECT *
            FROM {format_iena_settings}
            WHERE sectionid =?',
            array($idsection));
        return $requete;
    }

    /**
     * @return mixed
     */
    public function getId() {
        return $this->id;
    }

    /**
     * @param mixed $id
     *
     * @return self
     */
    public function setId($id) {
        $this->id = $id;

        return $this;
    }

    /**
     * @return mixed
     */
    public function getName() {
        return $this->name;
    }

    /**
     * @param mixed $name
     *
     * @return self
     */
    public function setName($name) {
        $this->name = $name;

        return $this;
    }

    /**
     * @return mixed
     */
    public function getIdCourse() {
        return $this->id_course;
    }

    /**
     * @param mixed $id_course
     *
     * @return self
     */
    public function setIdCourse($idcourse) {
        $this->id_course = $idcourse;

        return $this;
    }

    /**
     * @return mixed
     */
    public function getResources() {
        return $this->resources;
    }

    /**
     * @param mixed $resources
     *
     * @return self
     */
    public function setResources($resources) {
        $this->resources = $resources;

        return $this;
    }

    /**
     * @return mixed
     */
    public function getDate() {
        return $this->date;
    }

    /**
     * @param mixed $date
     *
     * @return self
     */
    public function setDate($date) {
        $this->date = $date;

        return $this;
    }

    /**
     * @return mixed
     */
    public function getAvailability() {
        return $this->availability;
    }

    /**
     * @param mixed $availability
     *
     * @return self
     */
    public function setAvailability($availability) {
        $this->availability = $availability;

        return $this;
    }

    /**
     * @return mixed
     */
    public function getVisibility() {
        return $this->visibility;
    }

    /**
     * @param mixed $visibility
     *
     * @return self
     */
    public function setVisibility($visibility) {
        $this->visibility = $visibility;

        return $this;
    }

    public function toArray() {
        $vars = [];
        foreach ($this as $varname => $varvalue) {
            $vars[$varname] = $varvalue;
        }
        return $vars;
    }
}
