<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
/**
 *
 * @package    format_iena
 * @copyright  2018 Softia/Université lorraine
 * @author     vrignaud camille
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

require_once('../../../config.php');
require_once('view/view_param_indicateur.php');
require_once('entity/course_format_iena_section_ressources.php');
require_once('entity/course_format_iena_sections.php');

global $COURSE, $DB, $USER;

$courseid = required_param('courseid', PARAM_INT);
$sectionid = required_param('sectionid', PARAM_INT);
$url = new moodle_url('/course/format/iena/param_indicateur.php', array('courseid' => $courseid));

$PAGE->set_pagelayout('course');
$PAGE->set_url($url);

if (!has_capability('moodle/course:sectionvisibility', $context = context_course::instance($courseid), $USER->id)) {
    $link = $CFG->wwwroot . '/course/view.php?id=' . $courseid;
    header("Location: {$link}");
    exit;
}
$course = $DB->get_record('course', array('id' => $courseid), '*', MUST_EXIST);
require_login($course, false, null);

$PAGE->set_title('Indicateurs de suivi');
$PAGE->set_heading('Indicateurs de suivi');

// Update in Database all tables format_iena_settings for each module.
if ($_POST) {
    if ($_POST['select-section']) {
        $sectionid = $_POST['select-section'];
        $sectionid = explode('-', $sectionid)[1];
    } else {
        $sectionid = "undefined";
    }

    // Récupération de l'état des modules du formulaire.
    $postedmoduleids = [];
    $y = 0;
    foreach ($_POST as $key => $formmodule) {
        $temp = explode($_POST['select-section'], $key);
        if (count($temp) > 1) {
            $postedmoduleids[$y] = $temp[0];
        }
        $y++;
    }

    $allmodules = explode("-", $_POST['all_modules']);

    $suivirecords = $DB->get_records('format_iena_settings', array('sectionid' => $sectionid));

    // Pour chaque activité du cours.
    foreach ($allmodules as $coursemodid) {
        $done = false;
        // Pour chaque activité suivie ou non en base.
        foreach ($suivirecords as $record) {
            // Si l'activité est en base (suivie ou non).
            if ($record->cmid == $coursemodid) {
                // L'activité est suivie en base (1 ou 0 => true, false).
                $issuivi = $record->hide == 1 ? true : false;
                // L'activité a été checkée pour être suivie à présent (true ou false).
                $isasksuivi = in_array($record->cmid, $postedmoduleids);
                // Si l'état de suivi de l'activité n'est pas le même que demandé.
                if ($issuivi !== $isasksuivi ) {
                    // Mise à jour de l'état de l'activité suivie.
                    $update = new stdClass();
                    $update->id = $record->id;
                    $update->hide = $isasksuivi ? 1 : 0;
                    $DB->update_record('format_iena_settings', $update, false);
                    // L'activité a été traitée.
                    $done = true;
                } else {
                    // L'activité n'a pas besoin d'être traitée.
                    $done = true;
                }
            }
        }
        // Si l'activité n'est pas en base (n'a pas été traitée).
        if ($done == false) {
            // Si l'activité a été checkée pour être suivie à présent (true ou false).
            if (in_array($coursemodid, $postedmoduleids) ) {
                $insert = new stdClass();
                $insert->courseid = $COURSE->id;
                $insert->cmid = $coursemodid;
                $insert->hide = 1;
                $insert->sectionid = $sectionid;
                $DB->insert_record('format_iena_settings', $insert, false);
            }
        }
    }

            $prevrecordexists = true;

        $link = $CFG->wwwroot . '/course/format/iena/suivi_unit.php?courseid=' . $courseid . '&sectionid=' . $sectionid;
        header("Location: {$link}");
        exit;

} else if ( $_GET['sectionid'] ) {

    echo $OUTPUT->header();

    $getsectionid = $_GET['sectionid'];

    $modinfo = get_fast_modinfo($COURSE->id);

    $sections = $modinfo->get_section_info_all();

    $suivicms = $DB->get_records_sql('SELECT id, cmid, hide
        FROM {format_iena_settings}
        WHERE courseid = ?
        AND sectionid = ?',
        array($COURSE->id, $getsectionid));

    $iscoursesection = false;
    $currentsectionname = "";

    $sectionsarr = [];

    foreach ($sections as $sectionnum => $section) {

        $sectionid = $section->__get('id');
        $sectionname = $section->__get('name');
        if ($sectionname == null) {
            $sectionname = "Section " . $sectionnum;
        }
        if ($sectionid == $getsectionid) {
            $iscoursesection = true;
            $currentsectionname = $sectionname;
            $currentsectionid = $sectionid;
        }

        $sectioncms = [];
        foreach ($modinfo->get_cms() as $module) {
            if ( $module->section == $sectionid ) {
                $mod = new stdClass();
                $mod->moduleid = $module->id;
                $mod->name = $module->name;
                $mod->courseid = $module->course;
                $mod->sectionid = $module->section;
                foreach ($suivicms as $suivi) {
                    if ($module->id == $suivi->cmid) {
                        if ($suivi->hide == 1) {
                            $mod->suivi = 1;
                        } else {
                            $mod->suivi = 0;
                        }
                    }
                }
                array_push($sectioncms, $mod);
            }
        }

        $sec = new stdClass();
        $sec->id = $sectionid;
        $sec->name = $sectionname;
        $sec->modules = $sectioncms;
        $sectionsarr[] = $sec;
    }

    if ($iscoursesection == false) {
        echo "<p class='alert alert-warning'>Id de section invalide</p>";
        echo $OUTPUT->footer();
    } else {
        $viewparamindicateur = new view_param_indicateur();
        echo $viewparamindicateur->get_content($sectionsarr, $currentsectionname, $currentsectionid);
        echo $OUTPUT->footer();
    }

} else {
    $link = $CFG->wwwroot . '/course/view.php?id=' . $courseid;
    header("Location: {$link}");
    exit;
}
