<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
/**
 *
 * @package    format_iena
 * @copyright  2018 Softia/Université lorraine
 * @author     vrignaud camille / Thomas Fradet
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

define('NO_OUTPUT_BUFFERING', true);
require_once('../../../config.php');
require_once('view/view_param_indicateur.php');
require_once('entity/course_format_iena_section_ressources.php');
require_once('entity/course_format_iena_sections.php');
require_once('entity/course_format_iena_groups.php');
$PAGE->requires->css('/course/format/iena/styles.css');







global $COURSE, $DB, $USER, $PAGE;

function init_page($course) {
    global $PAGE;
    // Defines the id of the course with a get parameter.
    // Getting DB information (*)  of the course.

    $PAGE->set_title($course->fullname);
    $PAGE->set_heading($course->fullname . " – " .get_string('table_progress', 'format_iena'));
    $PAGE->set_pagelayout('incourse');

    // Cache le menu dans le header.
    $coursenode = $PAGE->navbar->add(get_string('table_progress', 'format_iena'),
        null, navigation_node::TYPE_CONTAINER, null, 'suiviena');
    $coursenode->make_active();
    $coursenode->force_open();

}

function get_groups($context, $activegroupid, $progress, $groups) {
    global $USER, $COURSE;
    // Groupe du GET provenant du sélecteur de la page du cours
    // ou premier groupe de l'utilisateur, ou groupe 0 (tous les groupes).
    $groupsall = new StdClass();
    // TODO à supprimer si pas utilisé dans le JS (mettre dans la clause IF pour éviter un appel inutile si le GET existe).
    $currentusergroupsids = groups_get_user_groups($COURSE->id, $USER->id)[0];
    $currentusergroups = [];
    $othergroups = [];
    // Si pas de groupe dans le get ou groupe 0 (tous) mais pas le droit => premier groupe existant du user ou groupe 0 (tous).
    if ($activegroupid == null || ($activegroupid == 0 &&
        !has_capability('course/iena:suivi_edit', $context, $USER->id)) ) {
        if ( count($currentusergroupsids) == 0 ) {
            $activegroupid = 0;
        } else {
            $activegroupid = $currentusergroupsids[0];
        }
    }
    // Groupes du cours avec id, nom et liste des id utilisateur de tous les
    // membres (3 clefs d'un tableau de groupes : id, name, member).

    $activegroupname = "";

    foreach ($groups as $group) {
        // Récupération du nom du group actif au passage.
        if ( $group->id == $activegroupid ) {
            $activegroupname = $group->name;
            $group->selected = 'selected';
        }
        if (in_array($group->id, $currentusergroupsids)) {
            $currentusergroups[] = $group;
        } else {
            $othergroups[] = $group;
        }
    }

    $groupsall->groups = $othergroups;
    $groupsall->current_user_groups = $currentusergroups;
    return $groupsall;

}

// Formate l'achèvement d'activités pour le tableau de suivi. Pour chaque étudiant, on aura
// dans le bon ordre la liste des modules et le completionstate.
function format_progress($progress, $modules, $groups, $activegroupid, $activesectionid) {
    global $CFG, $COURSE;
    $students = array();
    foreach ($progress as $proginfo) {
        $progressstudent = new StdClass();
        $progressstudent->firstname = $proginfo->firstname;
        $progressstudent->lastname = $proginfo->lastname;
        $progressstudent->id = $proginfo->id;
        $progressstudent->email = $proginfo->email;
        $progressstudent->progress = array();
        $progressstudent->report_link = $CFG->wwwroot . "/report/outline/user.php?id=" .
            $progressstudent->id . "&course=" . $COURSE->id . "&mode=outline";
        $progressstudent->message_link = $CFG->wwwroot . "/message/index.php?id=" . $progressstudent->id;

        if ($activegroupid == 0) {
            $progressstudent->groups = "";
            foreach ($groups as $group) {
                if (in_array($progressstudent->id, $group->members)) {
                    $progressstudent->groups .= $group->name . " ";
                }
            }
        }

        foreach ($modules as $key => $module) {
            $moduleprogress = new StdClass();

            if (!isset($proginfo->progress[$module->id])) {
                $moduleprogress->completionstate = '0';
            } else {
                $moduleprogress->completionstate = $proginfo->progress[$module->id]->completionstate;
            }
            $moduleprogress->namemodule = $module->name;
            $moduleprogress->idmodule = $module->id;

            $progressstudent->progress[$key] = $moduleprogress;
        }

        $students[] = $progressstudent;
    }

    return $students;
}

function get_activities($completion, $activesectionid) {
    $activities = $completion->get_activities();
    $modules = [];
    foreach ($activities as $activity) {
        $module = new StdClass();
        $module->id = $activity->id;
        $module->name = $activity->name;
        $displayname = format_string($activity->name, true, array('context' => $activity->context));
        $module->displayname = strlen($displayname) > 30 ? mb_substr($displayname, 0, 29, 'UTF-8').'…' : $displayname;
        $module->section = $activity->section;
        $modules[] = $module;
        if ($activity->section == $activesectionid || $activesectionid == 0 ) {
            $module->visible = true;
        } else {
            $module->visible = false;
        }
    }
    return $modules;
}

function get_sections($activesectionid) {
    global $COURSE;
    // Liste des sections du cours.
    $modinfo = get_fast_modinfo($COURSE->id);
    $sectionsinfoall = $modinfo->get_section_info_all();
    $sections = [];

    foreach ($sectionsinfoall as $key => $sectioninfo) {
        $section = new StdClass();
        $section->id = $sectioninfo->id;
        $section->name = $sectioninfo->name === null || $sectioninfo->name === '' ? 'Section ' . $key : $sectioninfo->name;
        if ($section->id == $activesectionid) {
            $section->selected = "selected";
        }

        $sections[] = $section;
    }
    return $sections;
}

function set_filters($data, $filters, $symbols, $sections, $groups, $currentusergroups, $activegroupname, $activesectionid) {
    if (isset($_GET['filter'])) {
        $filtercomplete = $_GET['filter'];
        $symbols[mb_substr($filtercomplete, 0, 1, 'UTF-8')]->selected = "selected";
        $filters[mb_substr($filtercomplete, 1, null, 'UTF-8')]->selected = "selected";
    } else {
        $filters["0"]->selected = "selected";
        $symbols["≥"]->selected = "selected";
    }

    $data['filters'] = array_values($filters);
    $data['symbols'] = array_values($symbols);
    $data["sections"] = $sections;
    $data["groups"] = array_values($groups);
    $data['current_user_groups'] = $currentusergroups;

    if ($activegroupname == "") {
        $data['default_group'] = 'selected';
    }

    $data['data'] = array();
    $data['data']["sections"] = $sections;
    $data['data']["groups"] = array_values($groups);
    $data['data']['current_user_groups'] = $currentusergroups;
    $data['data']['active_group_name'] = $activegroupname;
    $data['data']['active_section_id'] = $activesectionid;

    return $data;
}

function set_data($data, $modules, $progress, $groups, $activegroupid, $activesectionid) {
    global $COURSE, $USER, $CFG;

    $data["modules"] = $modules;
    $countmodules = count($data["modules"]);

    $data["students"] = format_progress($progress, $modules, $groups, $activegroupid, $activesectionid);
    $countstudents = count($data["students"]);

    if ($countstudents > 0 && $countmodules > 0) {
        $data['count_results'] = count($data["students"]);
    }

    if (has_capability('course/iena:suivi_edit', $context = context_course::instance($COURSE->id), $USER->id)) {
        $data['link_bulkcompletion'] = $CFG->wwwroot . "/course/bulkcompletion.php?id=" . $COURSE->id;
    }

    $data['link_classicview'] = $CFG->wwwroot . "/report/progress/index.php?course=" . $COURSE->id;
    $data['link_editview']=$CFG->wwwroot . "/course/format/iena/suivi_edit.php?courseid=" . $COURSE->id;

    // Pour le téléchargement du tableau ?
    if (!isset($data['data'])) {
        $data['data'] = array();
    }

    $data['data'] = json_encode($data);
    return $data;
}

$filters = [
    "0" => (object)[
        "value" => "0",
        "name" => "0",
    ],
    "25" => (object)[
        "value" => "25",
        "name" => "25%",
    ],
    "50" => (object)[
        "value" => "50",
        "name" => "50%",
    ],
    "75" => (object)[
        "value" => "75",
        "name" => "75%",
    ],
    "100" => (object)[
        "value" => "100",
        "name" => "100%",
    ]
];

$symbols = [
    "=" => (object)[
        "value" => "=",
        "name" => "=",
    ],
    "<" => (object)[
        "value" => "<",
        "name" => "<",
    ],
    ">" => (object)[
        "value" => ">",
        "name" => ">",
    ],
    "≤" => (object)[
        "value" => "≤",
        "name" => "≤",
    ],
    "≥" => (object)[
        "value" => "≥",
        "name" => "≥",
    ]
];

$courseid = required_param('courseid', PARAM_INT);
// Define the url of the view.
$url = new moodle_url('/course/format/iena/suivi_unit.php', array('courseid' => $courseid));
$PAGE->set_url($url);

$course = $DB->get_record('course', array('id' => $courseid), '*', MUST_EXIST);
require_login($course);
require_once($CFG->libdir . '/completionlib.php');

$completion = new completion_info($course);
$context = context_course::instance($COURSE->id);

if (!has_capability('course/iena:suivi', $context = context_course::instance($courseid), $USER->id)) {
    $link = $CFG->wwwroot . '/course/view.php?id=' . $courseid;
    header("Location: {$link}");
    exit;
}

if (isset($_GET['groupid'])) {
    $activegroupid = $_GET['groupid'];
} else {
    $activegroupid = 0;
}

$progress = $completion->get_progress_all(
    '',
    array(),
    $activegroupid,
    'u.lastname ASC, u.firstname ASC',
    '',
    '',
    $context
);

$activesectionid = 0;
// Section du get acquise depuis le clic sur l'indicateur dans la page du cours,
// section depuis laquelle on a cliqué sur le bouton pour voir le suivi.
if (isset($_GET['sectionid'])) {
    $activesectionid = $_GET['sectionid'];
}

if ($activegroupid == 0) {
    // On récupère les ids des membres parce que dans l'excel on veut savoir qui appartient à quel groupe.
    $groups = groups_get_all_groups($COURSE->id, 0, 0, 'g.*', true);
} else {
    // On ne récupère pas les ids des membres.
    $groups = groups_get_all_groups($COURSE->id, 0, 0, 'g.*', false);
}

// If a post is sent trought the page.
if (isset($_POST['action']) && !empty($_POST['action'])) {
    // Si on change les filtres.
    $data = [];
    $modules = get_activities($completion, $activesectionid);

    $data = set_data($data, $modules, $progress, $groups, $activegroupid, $activesectionid);
    echo json_encode($data);
} else {
    init_page($course, $PAGE);
    echo $OUTPUT->header();
    $data = [];
    if(!$COURSE->enablecompletion){
        $data["completion_enabled"]=0;
        $data["link_enable"]= "<a href='".$CFG->wwwroot . '/course/edit.php?id=' . $courseid."'>sur ce lien</a>";
    }
    else{
        $data["completion_enabled"]=1;
        $currentusergroups = [];
        $activegroupname = "";
        

        $modules = get_activities($completion, $activesectionid);
        $groupsall = get_groups($context, $activegroupid, $progress, $groups);

        if (isset($groupsall->current_user_groups) && !empty($groupsall->current_user_groups)) {
            $currentusergroups = $groupsall->current_user_groups;
        }
        $groups = $groupsall->groups;
        $sections = get_sections($activesectionid);
        $data = set_filters($data, $filters, $symbols, $sections, $groups, $currentusergroups, $activegroupname, $activesectionid);
        $data = set_data($data, $modules, $progress, $groups, $activegroupid, $activesectionid);

        if (isset($_GET["msg_success"])) {
            $msg = $_GET["msg_success"];
            $data["msg_success"] = $msg;
        }

}
    
    $renderer = $PAGE->get_renderer('format_iena');
    $renderer->display_completion($data);
    echo $OUTPUT->footer();
}
